==> haskell-network2.8-2.8.0.1-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network2.8.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network
version:              2.8.0.1
visibility:           public
id:                   network-2.8.0.1-A5H5EzAE3baB3wat26dbj5
key:                  network-2.8.0.1-A5H5EzAE3baB3wat26dbj5
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto, Evan Borden
homepage:             https://github.com/haskell/network
synopsis:             Low-level networking interface
description:
    This package provides a low-level networking interface.

    In network-2.6 the @Network.URI@ module was split off into its own
    package, network-uri-2.6. If you'\''re using the @Network.URI@ module
    you can automatically get it from the right package by adding this
    to your .cabal file:

    > library
    >   build-depends: network-uri-flag

category:             Network
abi:                  57d723a467d43dfd1c76cfc3cf2047f4
exposed:              True
exposed-modules:
    Network Network.BSD Network.Socket Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal

hidden-modules:
    Network.Socket.ByteString.Internal Network.Socket.Types
    Network.Socket.ByteString.IOVec
    Network.Socket.ByteString.Lazy.Posix
    Network.Socket.ByteString.MsgHdr

import-dirs:          /usr/lib/ghc-8.10.2/site-local/network-2.8.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/network-2.8.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/network-2.8.0.1
hs-libraries:         HSnetwork-2.8.0.1-A5H5EzAE3baB3wat26dbj5
include-dirs:         /usr/lib/ghc-8.10.2/site-local/network-2.8.0.1/include
includes:             HsNet.h HsNetDef.h
depends:              base-4.14.1.0 bytestring-0.10.10.0 unix-2.7.2.2
ld-options:           "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces:   /usr/share/doc/haskell-network2.8/html/network.haddock
haddock-html:         /usr/share/doc/haskell-network2.8/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network2.8-2.8.0.1-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network2.8.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network
version:              2.8.0.1
visibility:           public
id:                   network-2.8.0.1-BD4fYrZOZhpFvdqyurIl2F
key:                  network-2.8.0.1-BD4fYrZOZhpFvdqyurIl2F
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto, Evan Borden
homepage:             https://github.com/haskell/network
synopsis:             Low-level networking interface
description:
    This package provides a low-level networking interface.

    In network-2.6 the @Network.URI@ module was split off into its own
    package, network-uri-2.6. If you'\''re using the @Network.URI@ module
    you can automatically get it from the right package by adding this
    to your .cabal file:

    > library
    >   build-depends: network-uri-flag

category:             Network
abi:                  992c46217baa0f7187a3daada57a45dd
exposed:              True
exposed-modules:
    Network Network.BSD Network.Socket Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal

hidden-modules:
    Network.Socket.ByteString.Internal Network.Socket.Types
    Network.Socket.ByteString.IOVec
    Network.Socket.ByteString.Lazy.Posix
    Network.Socket.ByteString.MsgHdr

import-dirs:          /usr/lib/ghc-8.10.2/site-local/network-2.8.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/network-2.8.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/network-2.8.0.1
hs-libraries:         HSnetwork-2.8.0.1-BD4fYrZOZhpFvdqyurIl2F
include-dirs:         /usr/lib/ghc-8.10.2/site-local/network-2.8.0.1/include
includes:             HsNet.h HsNetDef.h
depends:              base-4.14.1.0 bytestring-0.10.10.0 unix-2.7.2.2
ld-options:           "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces:   /usr/share/doc/haskell-network2.8/html/network.haddock
haddock-html:         /usr/share/doc/haskell-network2.8/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
